Learn R Programming

soundcorrs (version 0.4.0)

print.soundcorrs: A more reasonable display of a soundcorrs object.

Description

A more reasonable display of a soundcorrs object.

Usage

# S3 method for soundcorrs
print(x, ...)

Arguments

x

[soundcorrs] The soundcorrs object.

...

Unused; only for consistency with print.

Value

[soundcorrs] The same object that was given as x.

Details

A soundcorrs may be quite large and therefore difficult to digest for a human. This function reduces it to a brief, easy to understand summary.

See Also

soundcorrs

Examples

Run this code
# NOT RUN {
dataset <- loadSampleDataset ("data-abc")
dataset
# }

Run the code above in your browser using DataLab